﻿using Microsoft.VisualStudio.TestTools.UnitTesting;
using System;
using System.Text;
using System.Collections.Generic;
using System.Net;
using MIS.EN.Exchange;
using MIS.EN.Exchange.Entities;
using System.Configuration;

namespace MIS.EN.UnitTests.VS
{
    /// <summary>
    ///This is a test class for MIS.EN.Exchange.ExchangeStore and is intended
    ///to contain all MIS.EN.Exchange.ExchangeStore Unit Tests
    ///</summary>
    [TestClass()]
    public class ExchangeStoreTest
    {
        private TestContext testContextInstance;
        private static NetworkCredential credentials;
        private static Uri userMailBox;
        private static bool useFormsBasedAuthentication;
        private static bool useIsaServer2006;

        /// <summary>
        ///Gets or sets the test context which provides
        ///information about and functionality for the current test run.
        ///</summary>
        public TestContext TestContext
        {
            get
            {
                return this.testContextInstance;
            }
            set
            {
                this.testContextInstance = value;
            }
        }
        #region Additional test attributes

        //You can use the following additional attributes as you write your tests:
        
        //Use ClassInitialize to run code before running the first test in the class
        
        [ClassInitialize()]
        public static void ClassInitialize(TestContext testContext)
        {
            string username = ConfigurationManager.AppSettings["username"];
            string password = ConfigurationManager.AppSettings["password"];
            string domain = ConfigurationManager.AppSettings["domain"];
            string userMailBox = ConfigurationManager.AppSettings["userMailBox"];
            string useFormsBasedAuthentication = ConfigurationManager.AppSettings["useFormsBasedAuthentication"];
            string useIsaServer2006 = ConfigurationManager.AppSettings["useIsaServer2006"];

            ExchangeStoreTest.credentials = new NetworkCredential(username, password, domain);
            ExchangeStoreTest.userMailBox = new Uri(userMailBox);
            // If inside the firewall, always set these to false
            ExchangeStoreTest.useFormsBasedAuthentication = (useFormsBasedAuthentication.ToLower() == "true");
            ExchangeStoreTest.useIsaServer2006 = (useIsaServer2006.ToLower() == "true");
        }
        
        //Use ClassCleanup to run code after all tests in a class have run
        
        [ClassCleanup()]
        public static void ClassCleanup()
        {
        }
        
        //Use TestInitialize to run code before running each test
        
        [TestInitialize()]
        public void TestInitialize()
        {
        }
        
        //Use TestCleanup to run code after each test has run
        
        [TestCleanup()]
        public void TestCleanup()
        {
        }
        
        #endregion


        /// <summary>
        ///A test for Delete (Uri)
        ///</summary>
        [TestMethod()]
        public void DeleteTest()
        {
            ExchangeStore.Delete(new Uri(ExchangeStoreTest.userMailBox.ToString() + "/Calendar/San Diego Meeting.eml"),
                ExchangeStoreTest.credentials, ExchangeStoreTest.useFormsBasedAuthentication, ExchangeStoreTest.useIsaServer2006);
        }

        /// <summary>
        ///A test for DeleteAppointment (Appointment)
        ///</summary>
        [TestMethod()]
        public void DeleteAppointmentTest()
        {
            ExchangeStore store = new ExchangeStore(ExchangeStoreTest.credentials, ExchangeStoreTest.userMailBox,
                ExchangeStoreTest.useFormsBasedAuthentication, ExchangeStoreTest.useIsaServer2006);
            Appointment appointment = new Appointment();
            appointment.Href = ExchangeStoreTest.userMailBox.ToString() + "/Calendar/San Diego Meeting.eml";
            store.DeleteAppointment(appointment);
        }

        /// <summary>
        ///A test for DeleteContact (Contact)
        ///</summary>
        [TestMethod()]
        public void DeleteContactTest()
        {
            ExchangeStore store = new ExchangeStore(ExchangeStoreTest.credentials, ExchangeStoreTest.userMailBox,
                ExchangeStoreTest.useFormsBasedAuthentication, ExchangeStoreTest.useIsaServer2006);
            Contact contact = new Contact();
            contact.Href = ExchangeStoreTest.userMailBox.ToString() + "/Contacts/Joe Test.eml";
            store.DeleteContact(contact);
        }

        /// <summary>
        ///A test for DeleteTask (Task)
        ///</summary>
        [TestMethod()]
        public void DeleteTaskTest()
        {
            ExchangeStore store = new ExchangeStore(ExchangeStoreTest.credentials, ExchangeStoreTest.userMailBox,
                ExchangeStoreTest.useFormsBasedAuthentication, ExchangeStoreTest.useIsaServer2006);
            Task task = new Task();
            task.Href = ExchangeStoreTest.userMailBox.ToString() + "/Tasks/Test Task.eml";
            store.DeleteTask(task);
        }

        /// <summary>
        ///A test for GetAppointments ()
        ///</summary>
        [TestMethod()]
        public void GetAppointmentsTest()
        {
            ExchangeStore store = new ExchangeStore(ExchangeStoreTest.credentials, ExchangeStoreTest.userMailBox,
                ExchangeStoreTest.useFormsBasedAuthentication, ExchangeStoreTest.useIsaServer2006);
            IList<Appointment> appointments = store.GetAppointments();
            this.testContextInstance.WriteLine("Total Appointments:  {0}", appointments.Count);
        }

        /// <summary>
        ///A test for GetAppointments (DateTime, DateTime)
        ///</summary>
        [TestMethod()]
        public void GetAppointmentsWithDateRangeTest()
        {
            ExchangeStore store = new ExchangeStore(ExchangeStoreTest.credentials, ExchangeStoreTest.userMailBox,
                ExchangeStoreTest.useFormsBasedAuthentication, ExchangeStoreTest.useIsaServer2006);
            IList<Appointment> appointments = store.GetAppointments(DateTime.Parse("1/1/2007"), DateTime.Parse("2/1/2007"));
            this.testContextInstance.WriteLine("Total Appointments:  {0}", appointments.Count);
        }

        /// <summary>
        ///A test for GetContacts ()
        ///</summary>
        [TestMethod()]
        public void GetContactsTest()
        {
            ExchangeStore store = new ExchangeStore(ExchangeStoreTest.credentials, ExchangeStoreTest.userMailBox,
                ExchangeStoreTest.useFormsBasedAuthentication, ExchangeStoreTest.useIsaServer2006);
            IList<Contact> contacts = store.GetContacts();
            foreach (Contact contact in contacts)
            {
                this.testContextInstance.WriteLine("Name:  {0}", contact.Name);
            }
            this.testContextInstance.WriteLine("Total Contacts:  {0}", contacts.Count);
        }

        /// <summary>
        ///A test for GetTasks ()
        ///</summary>
        [TestMethod()]
        public void GetTasksTest()
        {
            ExchangeStore store = new ExchangeStore(ExchangeStoreTest.credentials, ExchangeStoreTest.userMailBox,
                ExchangeStoreTest.useFormsBasedAuthentication, ExchangeStoreTest.useIsaServer2006);
            IList<Task> tasks = store.GetTasks();
            foreach (Task task in tasks)
            {
                this.testContextInstance.WriteLine("Name:  {0}", task.Name);
            }
            this.testContextInstance.WriteLine("Total Tasks:  {0}", tasks.Count);
        }

        /// <summary>
        ///A test for SaveAppointment (Appointment)
        ///</summary>
        [TestMethod()]
        public void SaveAppointmentTest()
        {
            Appointment appointment = new Appointment("San Diego", DateTime.Parse("7/25/2006 11:30 AM"),
                DateTime.Parse("7/25/2006 12:30 PM"), InstanceType.Single, BusyStatus.Busy,
                MeetingStatus.Confirmed, false, false, 900, "San Diego Meeting", 
                "Meeting in San Diego", TimeZoneId.Pacific);
            ExchangeStore store = new ExchangeStore(ExchangeStoreTest.credentials, ExchangeStoreTest.userMailBox,
                ExchangeStoreTest.useFormsBasedAuthentication, ExchangeStoreTest.useIsaServer2006);
            store.SaveAppointment(appointment);
            this.testContextInstance.WriteLine(appointment.Href);
            Assert.IsTrue((appointment.Href.Length > 0));
        }

        /// <summary>
        ///A test for SaveContact (Contact)
        ///</summary>
        [TestMethod()]
        public void SaveContactTest()
        {
            Contact contact = new Contact("Joe", "Test", "11199 April Leigh Terrace", 
                "San Diego", "CA", "92126", "USA", MailingAddress.Home);
            ExchangeStore store = new ExchangeStore(ExchangeStoreTest.credentials, ExchangeStoreTest.userMailBox,
                ExchangeStoreTest.useFormsBasedAuthentication, ExchangeStoreTest.useIsaServer2006);
            store.SaveContact(contact);
            this.testContextInstance.WriteLine(contact.Href);
            Assert.IsTrue((contact.Href.Length > 0));
        }

        /// <summary>
        ///A test for SaveTaskTest (Task)
        ///</summary>
        [TestMethod()]
        public void SaveTaskTest()
        {
            Task task = new Task();
            task.Subject = "Test Task";
            task.TextDescription = "Test Task";

            ExchangeStore store = new ExchangeStore(ExchangeStoreTest.credentials, ExchangeStoreTest.userMailBox,
                ExchangeStoreTest.useFormsBasedAuthentication, ExchangeStoreTest.useIsaServer2006);
            store.SaveTask(task);
            this.testContextInstance.WriteLine(task.Href);
            Assert.IsTrue((task.Href.Length > 0));
        }
    }
}
